@@ -1,6 +1,7 @@
-use crate::{imp, io};
+use crate::imp;
+use crate::io::{self, OwnedFd};
 use imp::fs::{FdFlags, OFlags};
-use io_lifetimes::{AsFd, OwnedFd};
+use io_lifetimes::AsFd;
 
 /// `fcntl(fd, F_GETFD)`—Returns a file descriptor's flags.
 ///
